import {
  api,
  downloadFile,
  createApiUrl
} from '~/utils/axios';


/**
 * 导出产品系列
 * @param {Object} data
 * @return {Promise} api
 */
export function exportExcel(data) {
  downloadFile(createApiUrl('Products.ProductType/exportExcel'), data);
}

/**
 * 下载产品系列模板
 * @param {Object} data
 * @return {Promise} api
 */
export function downloadTemplate(data) {
  downloadFile(createApiUrl('Products.ProductType/downloadTemplate'), data);
}

/**
 * 导入产品系列
 * @param {Object} data
 * @return {Promise} api
 */
export const importExcel = createApiUrl('Products.ProductType/importExcel');

/**
 * 获取产品系列列表
 * @param {Object} data
 * @return {Promise} api
 */
export function getProductTypeTree(data) {
  return api.post('Products.ProductType/getProductTypeTree', data);
}

/**
 * 删除产品系列
 * @param {Object} data
 * @return {Promise} api
 */
export function deleteProductType(data) {
  return api.post('Products.ProductType/deleteProductType', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '删除失败'
  });
}

/**
 * 添加产品系列
 * @param {Object} data
 * @return {Promise} api
 */
export function addProductType(data) {
  return api.post('Products.ProductType/addProductType', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '添加失败'
  });
}
/**
 * 编辑产品系列
 * @param {Object} data
 * @return {Promise} api
 */
export function editProductType(data) {
  return api.post('Products.ProductType/editProductType', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '编辑失败'
  });
}